import { jsx as _jsx } from "react/jsx-runtime";
import SearchableList from './SearchableList';
import { render, screen } from '@testing-library/react';
describe('ContentTypeSelectionModal component', () => {
    afterEach(() => {
        jest.restoreAllMocks();
    });
    it('mounts and renders a list of items', () => {
        const items = ['asdf', 'bsdf'];
        const renderListItem = jest.fn().mockImplementation((item, idx) => _jsx("p", { children: item }, idx));
        const { unmount } = render(_jsx(SearchableList, { items: items, searchQuery: "", renderListItem: renderListItem, searchKeys: [] }));
        const listItem1 = screen.getByText(items[0]);
        const listItem2 = screen.getByText(items[1]);
        expect(listItem1).toBeTruthy();
        expect(listItem2).toBeTruthy();
        expect(renderListItem).toHaveBeenCalledWith('asdf');
        expect(renderListItem).toHaveBeenCalledWith('bsdf');
        unmount();
    });
    describe('searching for a content type', () => {
        it('fuzzy searches for content types', () => {
            const items = ['videos', 'blog posts', 'tutorials'];
            const searchQuery = 'Blgo-Potts';
            const renderListItem = jest.fn().mockImplementation((item, idx) => _jsx("p", { children: item }, idx));
            const { unmount } = render(_jsx(SearchableList, { items: items, searchQuery: searchQuery, renderListItem: renderListItem, searchKeys: [] }));
            const videos = screen.queryByText(items[0]);
            const blogPosts = screen.queryByText(items[1]);
            const tutorials = screen.queryByText(items[2]);
            expect(blogPosts).toBeVisible();
            expect(videos).toEqual(null);
            expect(tutorials).toEqual(null);
            unmount();
        });
    });
    describe('optional pinnedItems prop', () => {
        it('"pins" the items to the top of the filtered list, so that they are always rendered, even if the fuzzy search did not match them', () => {
            const renderListItem = jest.fn().mockImplementation((item, idx) => (_jsx("p", { "data-test-id": "car-item", children: item.title }, idx)));
            const car1 = {
                id: 123,
                title: 'A brand new car! Gotta love that "new car" smell!',
            };
            const car2 = {
                id: 456,
                title: 'A slightly used car! Fuel efficient and experienced!',
            };
            const items = [car1, car2];
            const { unmount } = render(_jsx(SearchableList, { items: items, searchQuery: car2.title, renderListItem: renderListItem, searchKeys: ['title'], pinnedItems: [car1] }));
            const renderedCarsList = screen.getAllByTestId('car-item');
            expect(renderedCarsList.length).toEqual(2);
            expect(renderedCarsList[0].textContent).toEqual(car1.title);
            expect(renderedCarsList[1].textContent).toEqual(car2.title);
            unmount();
        });
    });
});
