import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { AnalyticsBrowser } from '@segment/analytics-next';
import { useSDK } from '@contentful/react-apps-toolkit';
import getUserCookieConsent from './utils/getUserCookieConsent';
import typewriter from './typewriter/segment';
import { SegmentAnalyticsContext } from './segmentMarketplaceContext';
export const SegmentAnalyticsProvider = (props) => {
    const { writeKey } = props;
    const sdk = useSDK();
    const [segmentAnalytics, setSegmentAnalytics] = useState();
    const init = () => {
        if (segmentAnalytics) {
            typewriter.setTypewriterOptions({
                analytics: segmentAnalytics,
            });
            identify();
        }
        else {
            if (getUserCookieConsent(sdk, 'ANALYTICS')) {
                setSegmentAnalytics(AnalyticsBrowser.load({
                    writeKey: writeKey ||
                        process.env.SEGMENT_WRITE_KEY ||
                        process.env.REACT_APP_SEGMENT_WRITE_KEY,
                }));
            }
        }
    };
    useEffect(init, [segmentAnalytics]);
    const identify = () => {
        if (!segmentAnalytics || !getUserCookieConsent(sdk, 'ANALYTICS')) {
            return;
        }
        const payload = {
            environment_key: sdk.ids.environmentAlias || sdk.ids.environment,
            organization_key: sdk.ids.organization,
            space_key: sdk.ids.space,
        };
        segmentAnalytics.identify(sdk.ids.user, payload);
    };
    const getTrackedAppData = () => ({
        environment_key: sdk.ids.environmentAlias || sdk.ids.environment,
        organization_key: sdk.ids.organization,
        space_key: sdk.ids.space,
    });
    const trackEvent = (segmentEvent, eventData = {}) => {
        if (!segmentAnalytics) {
            return;
        }
        const trackedAppData = getTrackedAppData();
        typewriter[segmentEvent]({
            ...trackedAppData,
            ...eventData,
        });
    };
    return (_jsx(SegmentAnalyticsContext.Provider, { value: {
            trackEvent,
        }, children: props.children }));
};
